@@ -2,7 +2,7 @@ from os import environ
 from sys import argv
 
 from setux.targets import Local, SSH
-from setux.main.logger import debug
+from setux.logger import debug
 from setux.repl import commands
 from setux.repl.repl import repl, prompt
 from .usage import usage
